<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>DialogAbout</name>
    <message>
        <location filename="../dialogabout.ui" line="14"/>
        <source>About IMSProg</source>
        <translation>О программе IMSProg</translation>
    </message>
    <message>
        <source>IMSProg - free software I2C, SPI and MicroWire EEPROM/Flash chip programmer for CH341a devices. IMSProg supports 24Cxx, 25xx, 93Cxx, and M95xx series chips.</source>
        <translation type="vanished">IMSProg - это свободно распространяемая программа для программатора CH341a, поддерживающая микросхемы типов I2C, SPI NOR Flash и MicroWire. IMSProg поддерживает работу с 24Cxx, 25xxx, 93Cxx, M95xxx сериями микросхем</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="70"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;In this program &lt;a href=&quot;https://github.com/Simsys/qhexedit2/&quot;&gt;QhexEditor2&lt;/a&gt; widget and modified programmer &lt;a href=&quot;https://github.com/McMCCRU/SNANDer&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;SNANDer&lt;/span&gt;&lt;/a&gt; were used.&lt;/p&gt;&lt;p&gt;The page on GitHub is &lt;a href=&quot;https://github.com/bigbigmdm/IMSProg&quot;&gt;here&lt;/a&gt;, the support page is &lt;a href=&quot;https://antenna-dvb-t2.ru/IMSProg.php&quot;&gt;here&lt;/a&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;В этой программе используется виджет &lt;a href=&quot;https://github.com/Simsys/qhexedit2/&quot;&gt;QhexEditor2&lt;/a&gt; и модифицированный код программы &lt;a href=&quot;https://github.com/McMCCRU/SNANDer&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;SNANDer&lt;/span&gt;&lt;/a&gt; .&lt;/p&gt;&lt;p&gt;Страница на GitHub находится &lt;a href=&quot;https://github.com/bigbigmdm/IMSProg&quot;&gt;здесь&lt;/a&gt;, страница поддержки - &lt;a href=&quot;https://antenna-dvb-t2.ru/IMSProg.php&quot;&gt;здесь&lt;/a&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="120"/>
        <source>Version: </source>
        <translation>Версия: </translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="130"/>
        <source>1.1.4</source>
        <translation>1.1.4</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="48"/>
        <source>OR</source>
        <translation>или</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="26"/>
        <source>IMSProg - free software I2C, SPI and MicroWire EEPROM/Flash chip programmer for CH341a devices. IMSProg supports 24Cxx, 25xx, 93Cxx, AT45DBxx and M95xx series chips.</source>
        <translation>IMSProg - это свободно распространяемая программа для программатора CH341a, поддерживающая микросхемы типов I2C, SPI NOR Flash и MicroWire. IMSProg поддерживает работу с 24Cxx, 25xxx, 93Cxx, AT45DBxx, M95xxx сериями микросхем.</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="99"/>
        <source>Written by 2023 Mikhail Medvedev</source>
        <translation>Создано в 2023 году Михаилом Медведевым</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="169"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>DialogInfo</name>
    <message>
        <location filename="../dialoginfo.ui" line="14"/>
        <source>Connection info:</source>
        <translation>Информ. о подключении:</translation>
    </message>
    <message>
        <location filename="../dialoginfo.ui" line="36"/>
        <source>Slot:</source>
        <translation>Слот:</translation>
    </message>
    <message>
        <location filename="../dialoginfo.ui" line="43"/>
        <location filename="../dialoginfo.ui" line="61"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../dialoginfo.ui" line="54"/>
        <source>Adapter:</source>
        <translation>Адаптер:</translation>
    </message>
    <message>
        <location filename="../dialoginfo.ui" line="106"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>DialogRP</name>
    <message>
        <location filename="../dialogrp.ui" line="20"/>
        <source>Load block from file</source>
        <translation>Загрузить блок из файла</translation>
    </message>
    <message>
        <location filename="../dialogrp.ui" line="33"/>
        <source>All values in HEX format!</source>
        <translation>Все данные шестнадцатеричные</translation>
    </message>
    <message>
        <location filename="../dialogrp.ui" line="48"/>
        <source>Start address:</source>
        <translation>Стартовый адрес:</translation>
    </message>
    <message>
        <location filename="../dialogrp.ui" line="112"/>
        <source>Load</source>
        <translation>Загрузить</translation>
    </message>
</context>
<context>
    <name>DialogSFDP</name>
    <message>
        <location filename="../dialogsfdp.ui" line="14"/>
        <source>Information about SFDP and status registers</source>
        <translation>Информация о SFDP и регистрах статуса</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="47"/>
        <source>SFDP support:</source>
        <translation>Поддержка SFDP</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="67"/>
        <source>Minimum VCC:</source>
        <translation>Мин. VCC:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="87"/>
        <source>Maximum VCC:</source>
        <translation>Макс. VCC:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="107"/>
        <source>Chip size:</source>
        <translation>Объем МС:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="127"/>
        <source>Block size:</source>
        <translation>Размер блока:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="150"/>
        <source>Speeds:</source>
        <translation>Режимы:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="170"/>
        <source>OTP support:</source>
        <translation>Поддержка OTP:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="196"/>
        <source>Status Register 0</source>
        <translation>Регистр статуса 0:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="424"/>
        <source>SPR0</source>
        <translation>SPR0</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="449"/>
        <source>BP4</source>
        <translation>BP4</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="474"/>
        <source>BP3</source>
        <translation>BP3</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="499"/>
        <source>BP2</source>
        <translation>BP2</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="524"/>
        <source>BP1</source>
        <translation>BP1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="549"/>
        <source>BP0</source>
        <translation>BP0</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="574"/>
        <source>WEL</source>
        <translation>WEL</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="599"/>
        <source>WIP</source>
        <translation>WIP</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="830"/>
        <source>SUS1</source>
        <translation>SUS1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="855"/>
        <source>CMP</source>
        <translation>CMP</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="880"/>
        <source>LB3</source>
        <translation>LB3</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="905"/>
        <source>LB2</source>
        <translation>LB2</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="930"/>
        <source>LB1</source>
        <translation>LB1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="955"/>
        <source>SUS2</source>
        <translation>SUS2</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="980"/>
        <source>QE</source>
        <translation>QE</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1005"/>
        <source>SPR1</source>
        <translation>SPR1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="611"/>
        <source>Status Register 1</source>
        <translation>Регистр статуса 1:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1017"/>
        <source>Status register 2</source>
        <translation>Регистр статуса 2:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1195"/>
        <source>JEDEC info:</source>
        <translation>JEDEC информ.:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1301"/>
        <source>Man. ID</source>
        <translation>ID произв.</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1323"/>
        <source>Man. type</source>
        <translation>Тип произв.</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1345"/>
        <source>Capacity</source>
        <translation>Объем</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1357"/>
        <source>Unique ID:</source>
        <translation>ID микросхемы</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1398"/>
        <source>Read</source>
        <translation>Считать</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1426"/>
        <source>Write registers</source>
        <translation>Записать регистры</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1453"/>
        <location filename="../dialogsfdp.ui" line="1519"/>
        <location filename="../dialogsfdp.ui" line="1541"/>
        <source>(R)</source>
        <translation>(R)</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1475"/>
        <source>DRV1</source>
        <translation>DRV1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1497"/>
        <source>DRV0</source>
        <translation>DRV0</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1563"/>
        <source>WPS</source>
        <translation>WPS</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1585"/>
        <source>ADP</source>
        <translation>ADP</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1607"/>
        <source>ADS</source>
        <translation>ADS</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1693"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p/&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p/&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1731"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Legend:&lt;/p&gt;&lt;p&gt;** - Basic area&lt;br&gt;** - Extended area&lt;br&gt;** - Manufacture area &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Обозначения:&lt;/p&gt;&lt;p&gt;** - Основная область&lt;br&gt;** - Дополнит. область&lt;br&gt;** - Область производителя &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1776"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="79"/>
        <location filename="../dialogsfdp.cpp" line="99"/>
        <location filename="../dialogsfdp.cpp" line="208"/>
        <location filename="../dialogsfdp.cpp" line="228"/>
        <location filename="../dialogsfdp.cpp" line="254"/>
        <location filename="../dialogsfdp.cpp" line="283"/>
        <location filename="../dialogsfdp.cpp" line="298"/>
        <location filename="../dialogsfdp.cpp" line="415"/>
        <location filename="../dialogsfdp.cpp" line="417"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="99"/>
        <location filename="../dialogsfdp.cpp" line="208"/>
        <location filename="../dialogsfdp.cpp" line="228"/>
        <location filename="../dialogsfdp.cpp" line="254"/>
        <source>Error reading register!</source>
        <translation>Ошибка чтения регистра!</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="171"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt; Hex SFDP register data:
</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt; Данные области SFDP:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="172"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Addr:&lt;br&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Адр.&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="417"/>
        <source>Before writing the registers, please press the `Read` button!</source>
        <translation>Перез записью, пожалуйста, нажмите кнопку `Считать`!</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="79"/>
        <source>Error reading JEDEC ID!</source>
        <translation>Ошибка чтения JEDEC ID!</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="39"/>
        <source>Legend:</source>
        <translation>Обозначения:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="40"/>
        <source> - Basic area</source>
        <translation> - Основная область</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="41"/>
        <source> - Extended area</source>
        <translation> - Дополнит. область</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="42"/>
        <source> - Manufacture area</source>
        <translation> - Область производителя</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="283"/>
        <source>Error reading unique ID!</source>
        <translation>Ошибка чтения ID микросхемы!</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="298"/>
        <location filename="../dialogsfdp.cpp" line="415"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>Программатор CH341a не подключен!</translation>
    </message>
</context>
<context>
    <name>DialogSP</name>
    <message>
        <location filename="../dialogsp.ui" line="14"/>
        <source>Save part of image</source>
        <translation>Сохранить часть прошивки</translation>
    </message>
    <message>
        <location filename="../dialogsp.ui" line="27"/>
        <source>All values in HEX format!</source>
        <translation>Все данные шестнадцатеричные</translation>
    </message>
    <message>
        <location filename="../dialogsp.ui" line="42"/>
        <source>Start address:</source>
        <translation>Стартовый адрес</translation>
    </message>
    <message>
        <location filename="../dialogsp.ui" line="120"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../dialogsp.cpp" line="27"/>
        <source>End address</source>
        <translation>Кон. адрес</translation>
    </message>
    <message>
        <location filename="../dialogsp.cpp" line="28"/>
        <source>Length</source>
        <translation>Длина</translation>
    </message>
</context>
<context>
    <name>DialogSR</name>
    <message>
        <location filename="../dialogsr.ui" line="14"/>
        <source>Status register</source>
        <translation>Регистр статуса</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="296"/>
        <source>WPEN</source>
        <translation>WPEN</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="327"/>
        <location filename="../dialogsr.ui" line="358"/>
        <location filename="../dialogsr.ui" line="389"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="420"/>
        <source>BP1</source>
        <translation>BP1</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="451"/>
        <source>BP0</source>
        <translation>BP0</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="482"/>
        <source>WEN</source>
        <translation>WEN</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="513"/>
        <source>/RDY</source>
        <translation>/RDY</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="545"/>
        <source>Read</source>
        <translation>Считать</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="571"/>
        <source>Write</source>
        <translation>Записать</translation>
    </message>
    <message>
        <location filename="../dialogsr.cpp" line="55"/>
        <location filename="../dialogsr.cpp" line="69"/>
        <location filename="../dialogsr.cpp" line="108"/>
        <location filename="../dialogsr.cpp" line="111"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../dialogsr.cpp" line="55"/>
        <source>Error reading register!</source>
        <translation>Ошибка чтения регистра!</translation>
    </message>
    <message>
        <location filename="../dialogsr.cpp" line="69"/>
        <location filename="../dialogsr.cpp" line="111"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>Программатор CH341a не подключен!</translation>
    </message>
    <message>
        <location filename="../dialogsr.cpp" line="108"/>
        <source>Before writing the register, please press the `Read` button!</source>
        <translation>Перез записью, пожалуйста, нажмите кнопку `Считать`!</translation>
    </message>
</context>
<context>
    <name>DialogSecurity</name>
    <message>
        <location filename="../dialogsecurity.ui" line="14"/>
        <source>Security registers</source>
        <translation>Регистры безопасности</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="24"/>
        <source>Hex Editor</source>
        <translation>HEX-редактор</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="64"/>
        <source>Operations:</source>
        <translation>Операции:</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="93"/>
        <source>Reading security register data from the chip</source>
        <translation>Чтение данных регистра безопасности из микросхемы</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="96"/>
        <location filename="../dialogsecurity.ui" line="128"/>
        <location filename="../dialogsecurity.ui" line="160"/>
        <location filename="../dialogsecurity.ui" line="199"/>
        <location filename="../dialogsecurity.ui" line="231"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="125"/>
        <source>Erasing security register data</source>
        <translation>Стирание данных регистра безопасности</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="157"/>
        <source>Writing data to the security register</source>
        <translation>Запись данных в регистр безопасности</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="196"/>
        <source>Open a binary file from a computer</source>
        <translation>Открыть двоичный файл с компьютера</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="228"/>
        <source>Save the binary file on the computer</source>
        <translation>Сохранить двоичный файл на компьютере</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.ui" line="257"/>
        <source>Security register number:</source>
        <translation>Номер регистра безопасности:</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="161"/>
        <location filename="../dialogsecurity.cpp" line="171"/>
        <location filename="../dialogsecurity.cpp" line="245"/>
        <location filename="../dialogsecurity.cpp" line="279"/>
        <location filename="../dialogsecurity.cpp" line="350"/>
        <location filename="../dialogsecurity.cpp" line="375"/>
        <location filename="../dialogsecurity.cpp" line="408"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="161"/>
        <source>Error reading register!</source>
        <translation>Ошибка чтения регистра!</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="171"/>
        <location filename="../dialogsecurity.cpp" line="279"/>
        <location filename="../dialogsecurity.cpp" line="350"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>Программатор CH341a не подключен!</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="245"/>
        <source>Error writing register!</source>
        <translation>Ошибка записи регистра!</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="366"/>
        <source>Open file</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="375"/>
        <source>The file size exceeds the security register size.</source>
        <translation>Размер файла превышает размер регистра безопасности.</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="397"/>
        <source>Save file</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <location filename="../dialogsecurity.cpp" line="408"/>
        <source>Error saving file!</source>
        <translation>Ошибка сохранения файла!</translation>
    </message>
</context>
<context>
    <name>DialogSetAddr</name>
    <message>
        <location filename="../dialogsetaddr.ui" line="14"/>
        <source>Goto address</source>
        <translation>Перейти на адрес</translation>
    </message>
    <message>
        <location filename="../dialogsetaddr.ui" line="24"/>
        <source>All values in HEX format!</source>
        <translation>Все данные шестнадцатеричные</translation>
    </message>
    <message>
        <location filename="../dialogsetaddr.ui" line="39"/>
        <source>Address:</source>
        <translation>Адрес:</translation>
    </message>
    <message>
        <location filename="../dialogsetaddr.ui" line="90"/>
        <source>Go to</source>
        <translation>Перейти</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="928"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1021"/>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1024"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1045"/>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1048"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1033"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="29"/>
        <source>IMSProg - I2C/MicroWire/SPI CH341a Programmer</source>
        <translation>IMSProg - I2C/MicroWire/SPI программатор для CH341a</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="77"/>
        <source>Chip</source>
        <translation>Микросхема</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>Name</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Page size</source>
        <translation>Размер листа</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="285"/>
        <source>Block size</source>
        <translation>Размер блока</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="323"/>
        <source>VCC, Volt</source>
        <translation>Питание, В</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>4byte Addr.</source>
        <translation>4byte адрес</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="412"/>
        <location filename="../mainwindow.ui" line="1057"/>
        <source>Detect</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <location filename="../mainwindow.ui" line="1069"/>
        <source>Read</source>
        <translation>Считать</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="539"/>
        <source>i</source>
        <translation>i</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>I2C bus speed</source>
        <translation>Скор. шины I2C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="612"/>
        <source>Auto Options</source>
        <translation>Авто опции</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="629"/>
        <location filename="../mainwindow.ui" line="1081"/>
        <source>Erase</source>
        <translation>Стереть</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="639"/>
        <source>Program</source>
        <translation>Записать</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="649"/>
        <location filename="../mainwindow.ui" line="1105"/>
        <source>Verify</source>
        <translation>Проверить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="704"/>
        <source>Go!</source>
        <translation>Старт!</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="743"/>
        <location filename="../mainwindow.ui" line="959"/>
        <source>Hex Editor</source>
        <translation>HEX-редактор</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="805"/>
        <source>  JEDEC ID:</source>
        <translation>JEDEC ID:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="821"/>
        <source>CH341a:</source>
        <translation>CH341a:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="846"/>
        <source>border: 2px solid gray;border-radius: 5px;font-weight:600;border-style:inset;</source>
        <translation>border: 2px solid gray;border-radius: 5px;font-weight:600;border-style:inset;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="859"/>
        <source>CRC32:</source>
        <translation>CRC32:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="946"/>
        <source>Programmer</source>
        <translation>Программатор</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="969"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1036"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1060"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1072"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1084"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1093"/>
        <source>Write</source>
        <translation>Записать</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1096"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1108"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1117"/>
        <source>Undo</source>
        <translation>Назад</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1120"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1129"/>
        <source>Redo</source>
        <translation>Повтор</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1132"/>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1242"/>
        <source>Import from Intel HEX</source>
        <translation>Импорт из Intel HEX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1251"/>
        <source>Export to Intel HEX</source>
        <translation>Экспорт в Intel HEX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1260"/>
        <source>Extract from ASUS CAP</source>
        <translation>Извлечь из ASUS CAP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1269"/>
        <source>Goto address</source>
        <translation>Перейти на адрес</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1272"/>
        <source>Move the cursor to the entered address</source>
        <translation>Перемещает курсор на введенный адрес</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1275"/>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1284"/>
        <source>Security registers</source>
        <translation>Регистры безопасности</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1287"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1141"/>
        <source>Save Part</source>
        <translation>Сохранить часть</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1153"/>
        <source>Load Part</source>
        <translation>Загрузить часть</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1165"/>
        <source>Find / Replace</source>
        <translation>Поиск/замена</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1168"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1173"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1176"/>
        <source>About IMSProgrammer</source>
        <translation>О программе IMSProg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1179"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1188"/>
        <source>Checksum calculate</source>
        <translation>Пересчет CRC32</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1191"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1200"/>
        <source>Edit chips Database</source>
        <translation>Редактор базы микросхем</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1203"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1212"/>
        <location filename="../mainwindow.cpp" line="1639"/>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1215"/>
        <source>Forced stop of read, write, erase and verification operations</source>
        <translation>Принудительная остановка операций чтения, записи, стирания и проверки</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1218"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1227"/>
        <source>Chip info</source>
        <translation>Информ. о МС</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1230"/>
        <source>Information about SFDP and status registers</source>
        <translation>Информация о SFDP области и регистрах статуса</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1233"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="771"/>
        <location filename="../mainwindow.cpp" line="811"/>
        <location filename="../mainwindow.cpp" line="1286"/>
        <location filename="../mainwindow.cpp" line="2028"/>
        <location filename="../mainwindow.cpp" line="2096"/>
        <source>Current file: </source>
        <translation>Текущий файл:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Manufacture</source>
        <translation>Произв.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Size</source>
        <translation>Объем</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1688"/>
        <source>Opening DAT file</source>
        <translation>Открывается файл базы</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="225"/>
        <location filename="../mainwindow.cpp" line="233"/>
        <location filename="../mainwindow.cpp" line="239"/>
        <location filename="../mainwindow.cpp" line="265"/>
        <location filename="../mainwindow.cpp" line="266"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <location filename="../mainwindow.cpp" line="292"/>
        <location filename="../mainwindow.cpp" line="305"/>
        <location filename="../mainwindow.cpp" line="580"/>
        <location filename="../mainwindow.cpp" line="596"/>
        <location filename="../mainwindow.cpp" line="615"/>
        <location filename="../mainwindow.cpp" line="662"/>
        <location filename="../mainwindow.cpp" line="713"/>
        <location filename="../mainwindow.cpp" line="779"/>
        <location filename="../mainwindow.cpp" line="815"/>
        <location filename="../mainwindow.cpp" line="917"/>
        <location filename="../mainwindow.cpp" line="926"/>
        <location filename="../mainwindow.cpp" line="933"/>
        <location filename="../mainwindow.cpp" line="954"/>
        <location filename="../mainwindow.cpp" line="964"/>
        <location filename="../mainwindow.cpp" line="1150"/>
        <location filename="../mainwindow.cpp" line="1159"/>
        <location filename="../mainwindow.cpp" line="1165"/>
        <location filename="../mainwindow.cpp" line="1175"/>
        <location filename="../mainwindow.cpp" line="1199"/>
        <location filename="../mainwindow.cpp" line="1200"/>
        <location filename="../mainwindow.cpp" line="1214"/>
        <location filename="../mainwindow.cpp" line="1243"/>
        <location filename="../mainwindow.cpp" line="1267"/>
        <location filename="../mainwindow.cpp" line="1300"/>
        <location filename="../mainwindow.cpp" line="1547"/>
        <location filename="../mainwindow.cpp" line="1697"/>
        <location filename="../mainwindow.cpp" line="1851"/>
        <location filename="../mainwindow.cpp" line="1863"/>
        <location filename="../mainwindow.cpp" line="2115"/>
        <location filename="../mainwindow.cpp" line="2147"/>
        <location filename="../mainwindow.cpp" line="2165"/>
        <location filename="../mainwindow.cpp" line="2185"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1547"/>
        <source>File &apos;IMSProg_editor&apos; not found!</source>
        <translation>Не найден файл &apos;IMSProg_editor&apos;!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1697"/>
        <source>Error loading chip database file!</source>
        <translation>Ошибка загрузки файла базы микросхем!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1703"/>
        <source>Parsing DAT file</source>
        <translation>Обработка файла данных</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="196"/>
        <source>Reading data from </source>
        <translation>Считывается МС </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="225"/>
        <location filename="../mainwindow.cpp" line="917"/>
        <location filename="../mainwindow.cpp" line="1150"/>
        <source>Unsupported chip type!</source>
        <translation>Неизвестный тип микросхемы!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <location filename="../mainwindow.cpp" line="292"/>
        <location filename="../mainwindow.cpp" line="596"/>
        <location filename="../mainwindow.cpp" line="926"/>
        <location filename="../mainwindow.cpp" line="964"/>
        <location filename="../mainwindow.cpp" line="1159"/>
        <location filename="../mainwindow.cpp" line="1214"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>Программатор CH341a не подключен</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="239"/>
        <location filename="../mainwindow.cpp" line="1165"/>
        <source>Error reading block </source>
        <translation>Ошибка чтения блока </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <location filename="../mainwindow.cpp" line="954"/>
        <location filename="../mainwindow.cpp" line="1199"/>
        <source>Before reading from chip please press &apos;Detect&apos; button.</source>
        <translation>Перед считыванием нажмите кнопку &apos;Поиск&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="266"/>
        <source>Please select the chip parameters - manufacture and chip name</source>
        <translation>Выберите параметры микросхемы - &apos;Произв.&apos; и &apos;Название&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>The chip is not connect or missing!</source>
        <translation>Микросхема не установлена или повреждена!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="567"/>
        <location filename="../mainwindow.cpp" line="2020"/>
        <source>Saving file</source>
        <translation>Сохраняется файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <location filename="../mainwindow.cpp" line="2022"/>
        <source>Save file</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="580"/>
        <location filename="../mainwindow.cpp" line="1267"/>
        <source>Error saving file!</source>
        <translation>Ошибка сохранения файла!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="599"/>
        <source>Erasing the </source>
        <translation>Стирается МС </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="615"/>
        <location filename="../mainwindow.cpp" line="662"/>
        <location filename="../mainwindow.cpp" line="713"/>
        <source>Error erasing sector </source>
        <translation>Ошибка стирания сектора </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="759"/>
        <location filename="../mainwindow.cpp" line="805"/>
        <location filename="../mainwindow.cpp" line="2090"/>
        <source>Opening file</source>
        <translation>Открывается файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <location filename="../mainwindow.cpp" line="807"/>
        <location filename="../mainwindow.cpp" line="2092"/>
        <source>Open file</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="779"/>
        <location filename="../mainwindow.cpp" line="815"/>
        <source>The file size exceeds the chip size. Please select another chip or file or use `Save part` to split the file.</source>
        <translation>Размер файла превышает размер микросхемы. Пожалуйста, выберите другой тип микросхемы или файл или используйте `Сохранить часть`, чтобы разделить файл на части.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="879"/>
        <source>Writing data to </source>
        <translation>Запись данных в </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="933"/>
        <source>Error writing sector </source>
        <translation>Ошибка записи сектора </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1120"/>
        <source>Veryfing data from </source>
        <translation>Проверяются данные МС </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1175"/>
        <source>Error comparing data!
Address:   </source>
        <translation>Ошибка сравнения данных!
Адрес:   </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1175"/>
        <source>
Buffer: </source>
        <translation>
Буфер: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1175"/>
        <source>    Chip: </source>
        <translation> Микросхема: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1200"/>
        <source>Please select the chip parameters - manufacture and chip name.</source>
        <translation>Выберите параметры МС - &apos;Произв.&apos; и &apos;Название&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1209"/>
        <source>Ok!</source>
        <translation>Ok!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1209"/>
        <source>The operation was successful!</source>
        <translation>Операция успешно выполнена!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1243"/>
        <source>The end address must be greater than the starting address.</source>
        <translation>Конечный адрес больше начального!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1255"/>
        <source>Saving block</source>
        <translation>Сохраняется блок</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1257"/>
        <source>Save block</source>
        <translation>Сохранить блок</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1281"/>
        <source>Opening block</source>
        <translation>Открывается блок</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1283"/>
        <source>Open block</source>
        <translation>Открыть блок</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1300"/>
        <source>The end address out of image size!</source>
        <translation>Конечный адрес больше размера буфера!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1339"/>
        <source>Connected</source>
        <translation>Подключен</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1344"/>
        <source>Not connected</source>
        <translation>Не подключен</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1851"/>
        <source>Before working with the security registers, click the &apos;Detect&apos; button</source>
        <translation>Прежде чем работать с регистрами безопасности, нажмите кнопку &apos;Поиск&apos;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1863"/>
        <source>There are no security registers in this chip or the current version of IMSProg does not support this algorithm.</source>
        <translation>В этой микросхеме нет регистров безопасности, или текущая версия IMSProg не поддерживает этот алгоритм.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2115"/>
        <source>Not valid HEX format!</source>
        <translation>Неверный формат HEX!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2147"/>
        <source>The address is larger than the size of the chip!</source>
        <translation>Адрес больше, чем размер микросхемы!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2165"/>
        <location filename="../mainwindow.cpp" line="2185"/>
        <source>Checksum error!</source>
        <translation>Ошибка контрольной суммы!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1639"/>
        <source>Operation aborted!</source>
        <translation>Операция прервана!</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../searchdialog.ui" line="14"/>
        <source>QHexEdit - Find/Replace</source>
        <translation>HEX-редактор - поиск/замена</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="26"/>
        <source>Find</source>
        <translation>Найти</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="33"/>
        <location filename="../searchdialog.ui" line="78"/>
        <source>Hex</source>
        <translation>Hex</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="38"/>
        <location filename="../searchdialog.ui" line="83"/>
        <source>UTF-8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="71"/>
        <source>Replace</source>
        <translation>Заменить</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="116"/>
        <source>Options</source>
        <translation>Опции:</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="122"/>
        <source>&amp;Backwards</source>
        <translation>Поиск назад</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="129"/>
        <source>&amp;Prompt on replace</source>
        <translation>Подсказка при замене</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="150"/>
        <source>Standard headers:</source>
        <translation>Стандартные заголовки:</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="191"/>
        <source>ZIP</source>
        <translation>ZIP</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="213"/>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="235"/>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="257"/>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="286"/>
        <source>TAR</source>
        <translation>TAR</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="308"/>
        <source>UEFI</source>
        <translation>UEFI</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="330"/>
        <source>BIOS</source>
        <translation>BIOS</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="352"/>
        <source>GPT</source>
        <translation>GPT</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="385"/>
        <source>&amp;Find</source>
        <translation>Найти</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="388"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="413"/>
        <source>&amp;Replace</source>
        <translation>Заменить</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="435"/>
        <source>Replace &amp;All</source>
        <translation>Заменить все</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="457"/>
        <source>&amp;Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../searchdialog.cpp" line="87"/>
        <location filename="../searchdialog.cpp" line="113"/>
        <source>QHexEdit</source>
        <translation>QHexEdit</translation>
    </message>
    <message>
        <location filename="../searchdialog.cpp" line="87"/>
        <source>%1 occurrences replaced.</source>
        <translation>Заменено %1 вхождение.</translation>
    </message>
    <message>
        <location filename="../searchdialog.cpp" line="114"/>
        <source>Replace occurrence?</source>
        <translation>Заменить возникновение?</translation>
    </message>
</context>
<context>
    <name>UndoStack</name>
    <message>
        <location filename="../commands.cpp" line="130"/>
        <source>Inserting %1 bytes</source>
        <translation>Вставлено %1 байт</translation>
    </message>
    <message>
        <location filename="../commands.cpp" line="152"/>
        <source>Delete %1 chars</source>
        <translation>Удалено %1 симв.</translation>
    </message>
    <message>
        <location filename="../commands.cpp" line="177"/>
        <source>Overwrite %1 chars</source>
        <translation>Заменено %1 симв.</translation>
    </message>
</context>
</TS>
